#!/bin/sh
#
# @(#)12  1.15  src/oss/common/pd_utils/gskit_util/cert_test.sh, oss.common.src, oss600, 071114b 11/21/07 10:29:20
#
# 5698-PDO
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2003,2006. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# This script will try to extract information from the ldapcacert.b64
# file, and try to run an idsldapsearch command, using a 
# Key database (kdb) file created with the certificate.
#
# This script is intended for use by IBM Customer Support.
# Should be run on a machine which has AMRTE configured.
#  Usage:
#     /opt/pdos/sbin/cert_test.sh  <certificate> [user registry server hostname]
#
# Examples uses for this script:
#   1. Used as a pre-config check of the certificate file to check
#      its lifetime and to make sure yo can talk to the  User Registry server 
#      over SSL using this certificate.
#   2. Used to check the lifetime of the certificate to determine if
#      if it time to refresh the certificate. Note: The refresh of the
#      certificate used by AMOS to communicate with User Registry server is a
#      manual process. An administrator must check the lifetime of the ldapcert
#      as part of routine maintenance.
#
# Define many things
LDAP1="/opt/IBM/ldap/V6.0/bin/idsldapsearch"
LDAP2="/opt/ibm/ldap/V6.0/bin/idsldapsearch"
LDAP3="/bin/idsldapsearch"
LDAP4="/usr/bin/idsldapsearch"
LDAP5="/usr/ldap/bin/idsldapsearch"
LDAP6="/usr/IBMldap/bin/idsldapsearch"
PDCONF="/opt/PolicyDirector/etc/pd.conf"
PDCONFUTIL="/opt/PolicyDirector/sbin/pdconf"
PDURH_STANZA="pdrte"
PDURH="user-reg-host"
PDFIPS_STANZA="ssl"
PDFIPS="ssl-enable-fips"
GSKCMD1="/usr/bin/gsk7capicmd"
GSKCMD2="/usr/local/ibm/gsk7/bin/gsk7capicmd"
FH=$$
CKDB=/tmp/cert_test.${FH}
CPWD="secret"
CLABEL="cert_test"
osseal_pdosshowmsg=/opt/pdos/bin/pdosshowmsg
SOURCING="/opt/pdos/etc/.cert_test_args"

#
cat_file=pdosr.cat
failed=35a6109d
ok=35a6109e
am_not_found=35a610a0
ldap_host_not_found=35a610a1
ldap_search_not_found=35a610a2
create_kdb_msg=0x35a610b5
gskcmd_not_found=0x35a610b6
cert_details=0x35a610b7
file_not_found=0x35a610b8
cert_test_usage=0x35a610b9
ping_userreg_server=35a610ba

#
# PrintMessage <default-string>
#
PrintMessage() {
        default=$1
        shift
        if [ -x ${osseal_pdosshowmsg} ]
        then
                if ${osseal_pdosshowmsg} ${cat_file} "$@"
                then
                        return 0
                fi
        fi
        echo "$default"
        return 0
}



### Ro u t i n e s ###
create_kdb() {
    PrintMessage "Creating Key Database file." ${create_kdb_msg}
    
    if [ $GSKCMD = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0182E   Could not find the gsk7capicmd utility." ${gskcmd_not_found}
        return
    fi

    # Create a temporary kdb
    ${GSKCMD} -keydb -create -db ${CKDB}.kdb -stash -pw ${CPWD} -type cms -expire 10 $FIPSFLAG
    # Import the specified certificate
    ${GSKCMD} -cert -add -db ${CKDB}.kdb -pw ${CPWD} -label ${CLABEL} -file ${Cert} $FIPSFLAG
    # Show the details of the kdb file.
    PrintMessage "Certificate details:" ${cert_details}
    ${GSKCMD} -cert -details -db ${CKDB}.kdb -pw ${CPWD} -label ${CLABEL} $FIPSFLAG
}

remove_kdb() {
    # Remove the temporary kdb files.
    rm -f ${CKDB}.*
}

set_ldap() {
    if [ -x $LDAP1 ]; then
        LDAP=$LDAP1
    elif [ -x $LDAP2 ]; then
        LDAP=$LDAP2
    elif [ -x $LDAP3 ]; then
        LDAP=$LDAP3
    elif [ -x $LDAP4 ]; then
        LDAP=$LDAP4
    elif [ -x $LDAP5 ]; then
        LDAP=$LDAP5
    elif [ -x $LDAP6 ]; then
        LDAP=$LDAP6
    else
        LDAP="NOT_FOUND"
    fi

    if [ -f $PDCONF ]; then
       LDAPHOST=`$PDCONFUTIL -f $PDCONF getentry $PDURH_STANZA $PDURH`
    else
       LDAPHOST="NOT_FOUND"
    fi
}

set_gskcmd()
{
    if [ -x $GSKCMD1 ]; then
        GSKCMD=$GSKCMD1
    elif [ -x $GSKCMD2 ]; then
        GSKCMD=$GSKCMD2
    else
       GSKCMD="NOT_FOUND"
    fi
}

ping_ldap_ssl() {
    PrintMessage "\nTesting connectivity to User Registry Server (SSL)" ${ping_userreg_server}
    if [ $LDAP = "NOT_FOUND" ]; then
	PrintMessage "Could not find the idsldapsearch utility." ${ldap_search_not_found}
        return
    fi
    if [ $LDAPHOST = "NOT_FOUND" ]; then
	PrintMessage "Could not find the User Registry server hostname in the configuration file, /opt/PolicyDirector/etc/pd.conf."  ${ldap_host_not_found}
        return
    fi
    
    $LDAP $LDAPFIPSFLAG -h $LDAPHOST -Z -K ${CKDB}.kdb $LDAPARGS -b "" -s base -v objectclass=* 1>/dev/null 2>/dev/null
    case $? in
        0) PrintMessage "    OK" ${ok}
           ;;
        *) PrintMessage "    FAILED" ${failed}
           ;;
    esac
}

set_fipsmode ()
{
    if [ -f $PDCONF ]; then
        FIPS_SETTING=`$PDCONFUTIL -f $PDCONF getentry $PDFIPS_STANZA $PDFIPS 2>/dev/null`
	case $? in 
	0) if [ $FIPS_SETTING = "yes" ]; then
	    FIPSFLAG="-fips"
	    LDAPFIPSFLAG="-x"
	   else
	    FIPSFLAG=""	
	    LDAPFIPSFLAG=""
	   fi
	   ;;
	*) FIPSFLAG=""
	   LDAPFIPSFLAG=""
	   ;;
	esac
    else
	PrintMessage "AOSSR0160E   Could not find the Tivoli Access Manager Runtime configuration files." ${am_not_found}
	exit 1;
    fi
}

### M A I N ###
#
# Check that we have an argument:
if [ $# -eq 2 ]; then
    set_ldap
    LDAPHOST=$2
elif [ $# -eq 1 ]; then
    set_ldap
else
    PrintMessage "Usage: cert_test.sh <certificate> [user registry server]" ${cert_test_usage}
    exit 1;
fi

# defect 79730:  Allow user to source in options for ldapsearch.  Either by
# defining an LDAPARGS variable or creating a file in /opt/pdos/etc called
# .cert_test_args that contains a defined LDAPARGS variable.

if [ x"$LDAPARGS" = x ] ;then
   # if the .cert_test_args file exists, then source the file
   if [ -f $SOURCING ] ;then
      . $SOURCING
   fi
fi


# Set the path name for the GSK utility
set_gskcmd

#
# Check if we are asking for help  -?
if [ "$1" = "-?" ]; then
    PrintMessage "Usage: cert_test.sh <certificate> [user registry server]" ${cert_test_usage}
    exit 1;
fi

# Set the FIPS mode
set_fipsmode

#
# Check if the file exists.
Cert=$1
if [ ! -f ${Cert} ]; then
    PrintMessage "AOSSR0184E   File not found: ${Cert}" ${file_not_found}
    exit 1;
fi
#
# Create a key database file based on the certificate, display its
# information and ping the ldap server.
create_kdb
ping_ldap_ssl
remove_kdb

exit 0




