#!/bin/sh
#
# 5698-PDO
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2003,2006. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# @(#)50  1.16  src/oss/common/pd_utils/server_ping.sh, oss.common.src, oss600, 060222a 2/15/06 15:58:30
#
# This script will try the connection to PD and LDAP servers
# using a configured AMOS
# Define many things
PDADM="/opt/PolicyDirector/bin/pdadmin"
PDSTATUS="/opt/PolicyDirector/.configure/PDRTE"
PDSTATUSLinux="/opt/PolicyDirector/.configure/PDRTE-PD"
PDBAS="/opt/PolicyDirector/sbin/bassslcfg"
PDCONF="/opt/PolicyDirector/etc/pd.conf"
PDCONFUTIL="/opt/PolicyDirector/sbin/pdconf"
PDMASTER_STANZA="manager"
PDMH="master-host"
PDMP="master-port"
PDURH_STANZA="pdrte"
PDURH="user-reg-host"
PDFIPS_STANZA="ssl"
PDFIPS="ssl-enable-fips"
PDTEST="user list root 0"
LDAP1="/opt/IBM/ldap/V6.0/bin/idsldapsearch"
LDAP2="/opt/ibm/ldap/V6.0/bin/idsldapsearch"
LDAP3="/bin/idsldapsearch"
LDAP4="/usr/bin/idsldapsearch"
LDAP5="/usr/ldap/bin/idsldapsearch"
LDAP6="/usr/IBMldap/bin/idsldapsearch"
AMOSKDB="/var/pdos/certs/pdosd.kdb"
osseal_pdosshowmsg=/opt/pdos/bin/pdosshowmsg

cat_file=pdosr.cat
failed=35a6109d
ok=35a6109e
ping_server=35a6109f
am_not_found=35a610a0
ldap_host_not_found=35a610a1
ldap_search_not_found=35a610a2
amos_kdb_not_found=35a610a3

#
# PrintMessage <default-string> <message-id> [<arg> [<arg> ...]]
#
PrintMessage() {
        default="$1"
        shift
        if [ -x ${osseal_pdosshowmsg} ]
        then
                if ${osseal_pdosshowmsg} ${cat_file} "$@"
                then
                        return 0
                fi
        fi

        echo "$default"
        return 0
}



### Ro u t i n e s ###
ping_am() {
    PrintMessage "Testing connectivity to the Tivoli Access Manager policy server" ${ping_server} "Tivoli Access Manager policy server"
    if [ -f $PDSTATUS -o -f $PDSTATUSLinux ] && [ -f $PDCONF -a -f $PDBAS ]; then
        AMHOST=`$PDCONFUTIL -f $PDCONF getentry $PDMASTER_STANZA $PDMH`
        AMPORT=`$PDCONFUTIL -f $PDCONF getentry $PDMASTER_STANZA $PDMP`

        $PDBAS -ping -h $AMHOST -p $AMPORT 1>/dev/null 2>/dev/null
     
  	     case $? in
            0) PrintMessage "    OK" ${ok} 
               ;;
            *) PrintMessage "    FAILED" ${failed}
               ;;
        esac
    else 
        PrintMessage "  AOSSR0160E   Could not find the Tivoli Access Manager Runtime configuration files." ${am_not_found}
    fi
}

set_ldap() {
    if [ -x $LDAP1 ]; then
        LDAP=$LDAP1
    elif [ -x $LDAP2 ]; then
        LDAP=$LDAP2
    elif [ -x $LDAP3 ]; then
        LDAP=$LDAP3
    elif [ -x $LDAP4 ]; then
        LDAP=$LDAP4
    elif [ -x $LDAP5 ]; then
        LDAP=$LDAP5
    elif [ -x $LDAP6 ]; then
        LDAP=$LDAP6
    else
        LDAP="NOT_FOUND"
    fi

    if [ -f $PDCONF ]; then
       LDAPHOST=`$PDCONFUTIL -f $PDCONF getentry $PDURH_STANZA $PDURH`
    else
       LDAPHOST="NOT_FOUND"
    fi

    if [ -f $AMOSKDB ]; then
       AMOSKDB=$AMOSKDB
    else
       AMOSKDB="NOT_FOUND"
    fi
}

# FIPS mode is retrieved from the pd.conf file. If FIPS is enabled in the pd.conf file
# idsldapsearch must be called with the -x flag when communicating with the LDAP
# server over SSL. 

set_fipsmode ()
{
    if [ -f $PDCONF ]; then
	FIPS_SETTING=`$PDCONFUTIL -f $PDCONF getentry $PDFIPS_STANZA $PDFIPS 2>/dev/null`
	case $? in
	0) if [ $FIPS_SETTING = "yes" ]; then
		LDAPFIPSFLAG="-x"
           else
		LDAPFIPSFLAG=""
           fi
	;;
	*) LDAPFIPSFLAG=""
	;;
	esac
    else
        PrintMessage "  AOSSR0160E   Could not find the Tivoli Access Manager Runtime configuration files." ${am_not_found}
        exit 1;
    fi
}

ping_ldap() {
    PrintMessage "Testing connectivity to the User Registry Server (Non SSL)" ${ping_server} "User Registry Server (Non SSL)"
    if [ $LDAP = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0162E   Could not find the idsldapsearch utility." ${ldap_search_not_found}
        return
    fi
    if [ $LDAPHOST = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0161E   Could not find the User Registry server hostname in the configuration file, /opt/PolicyDirector/etc/pd.conf." ${ldap_host_not_found}
        return
    fi
    
    $LDAP -h $LDAPHOST -b "" -s base -v objectclass=* 1>/dev/null 2>/dev/null
    case $? in
        0) PrintMessage "    OK" ${ok}
           ;;
        *) PrintMessage "    FAILED" ${failed}
           ;;
    esac
}

ping_ldap_ssl() {
    PrintMessage "Testing connectivity to the User Registry Server (SSL)" ${ping_server} "User Registry Server (SSL)"
    if [ $LDAP = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0162E   Could not find the idsldapsearch utility." ${ldap_search_not_found}
        return
    fi
    if [ $LDAPHOST = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0161E   Could not find the User Registry server hostname in the configuration file, /opt/PolicyDirector/etc/pd.conf." ${ldap_host_not_found}
        return
    fi
    if [ $AMOSKDB = "NOT_FOUND" ]; then
	PrintMessage "AOSSR0163E   Could not find the Tivoli Access Manager for Operating Systems key database file, /var/pdos/certs/pdosd.kdb." ${amos_kdb_not_found} 
        return
    fi
    
    $LDAP $LDAPFIPSFLAG -h $LDAPHOST -Z -K $AMOSKDB -b "" -s base -v objectclass=* 1>/dev/null 2>/dev/null
    case $? in
        0) PrintMessage "    OK" ${ok}
           ;;
        *) PrintMessage "    FAILED" ${failed}
           ;;
    esac
}


### M A I N ###
ping_am
set_ldap
set_fipsmode
ping_ldap
ping_ldap_ssl
